@@ -1,3 +1,11 @@
+"""
+The following documents the pyfar filters. Visit the
+:doc:`gallery:gallery/interactive/pyfar_filter_types`
+for an overview of the different filters and the
+:doc:`gallery:gallery/interactive/pyfar_filtering`
+for more information on using pyfar filter objects.
+"""
+
 from .band_filter import (
     butterworth,
     chebyshev1,
