@@ -1,7 +1,12 @@
 """
 Collection of sampling schemes and related functionality. For information on
 the used coordinate systems refer to the
-:py:mod:`concepts <pyfar._concepts.coordinates>`.
+:py:mod:`Coordinates documentation <pyfar.classes.coordinates>`.
+
+.. warning::
+
+    This module will be deprecated in pyfar v0.8.0 in favor of
+    :py:mod:`spharpy.samplings <spharpy.samplings>`.
 """
 
 from .spatial import SphericalVoronoi, calculate_sph_voronoi_weights
