@@ -1,8 +1,11 @@
 import numpy as np
 import urllib3
+from urllib3.exceptions import InsecureRequestWarning
+import warnings
 import os
 import scipy.io as sio
 import pyfar
+from pyfar.classes.warnings import PyfarDeprecationWarning
 
 from . import external
 
@@ -11,6 +14,9 @@ def cart_equidistant_cube(n_points):
     """
     Create a cuboid sampling with equidistant spacings in x, y, and z.
 
+    This function will be deprecated in pyfar 0.8.0 in favor
+    of :py:func:`spharpy.samplings.cube_equidistant`.
+
     The cube will have dimensions 1 x 1 x 1.
 
     Parameters
@@ -27,6 +33,11 @@ def cart_equidistant_cube(n_points):
         Sampling positions. Does not contain sampling weights.
 
     """
+    warnings.warn((
+        "This function will be deprecated in pyfar 0.8.0 in favor "
+        "of spharpy.samplings.cube_equidistant."),
+            PyfarDeprecationWarning)
+
     if np.size(n_points) == 1:
         n_x = n_points
         n_y = n_points
@@ -49,7 +60,6 @@ def cart_equidistant_cube(n_points):
         x_grid.flatten(),
         y_grid.flatten(),
         z_grid.flatten(),
-        domain='cart',
         comment='equidistant cuboid sampling grid')
 
     return sampling
@@ -60,6 +70,9 @@ def sph_dodecahedron(radius=1.):
     Generate a sampling based on the center points of the twelve
     dodecahedron faces.
 
+    This function will be deprecated in pyfar 0.8.0 in favor
+    of :py:func:`spharpy.samplings.dodecahedron`.
+
     Parameters
     ----------
     radius : number, optional
@@ -70,8 +83,11 @@ def sph_dodecahedron(radius=1.):
     sampling : Coordinates
         Sampling positions. Sampling weights can be obtained from
         :py:func:`calculate_sph_voronoi_weights`.
-
     """
+    warnings.warn((
+        "This function will be deprecated in pyfar 0.8.0 in favor "
+        "of spharpy.samplings.dodecahedron."),
+            PyfarDeprecationWarning)
 
     dihedral = 2 * np.arcsin(np.cos(np.pi / 3) / np.sin(np.pi / 5))
     R = np.tan(np.pi / 3) * np.tan(dihedral / 2)
@@ -105,8 +121,8 @@ def sph_dodecahedron(radius=1.):
         phi3 + np.pi / 3]), 2)
     rad = radius * np.ones(np.size(theta))
 
-    sampling = pyfar.Coordinates(
-        phi, theta, rad, domain='sph', convention='top_colat',
+    sampling = pyfar.Coordinates.from_spherical_colatitude(
+        phi, theta, rad,
         comment='dodecahedral sampling grid')
     return sampling
 
@@ -115,6 +131,9 @@ def sph_icosahedron(radius=1.):
     """
     Generate a sampling from the center points of the twenty icosahedron faces.
 
+    This function will be deprecated in pyfar 0.8.0 in favor
+    of :py:func:`spharpy.samplings.icosahedron`.
+
     Parameters
     ----------
     radius : number, optional
@@ -127,6 +146,11 @@ def sph_icosahedron(radius=1.):
         :py:func:`calculate_sph_voronoi_weights`.
 
     """
+    warnings.warn((
+        "This function will be deprecated in pyfar 0.8.0 in favor "
+        "of spharpy.samplings.icosahedron."),
+            PyfarDeprecationWarning)
+
     gamma_R_r = np.arccos(np.cos(np.pi / 3) / np.sin(np.pi / 5))
     gamma_R_rho = np.arccos(1 / (np.tan(np.pi / 5) * np.tan(np.pi / 3)))
 
@@ -139,9 +163,8 @@ def sph_icosahedron(radius=1.):
     phi = np.concatenate((np.tile(phi, 2), np.tile(phi + np.pi / 5, 2)))
 
     rad = radius * np.ones(20)
-    sampling = pyfar.Coordinates(
+    sampling = pyfar.Coordinates.from_spherical_colatitude(
         phi, theta, rad,
-        domain='sph', convention='top_colat',
         comment='icosahedral spherical sampling grid')
     return sampling
 
@@ -150,6 +173,9 @@ def sph_equiangular(n_points=None, sh_order=None, radius=1.):
     """
     Generate an equiangular sampling of the sphere.
 
+    This function will be deprecated in pyfar 0.8.0 in favor
+    of :py:func:`spharpy.samplings.equiangular`.
+
     For detailed information, see [#]_, Chapter 3.2.
     This sampling does not contain points at the North and South Pole and is
     typically used for spherical harmonics processing. See
@@ -179,6 +205,11 @@ def sph_equiangular(n_points=None, sh_order=None, radius=1.):
            Berlin, Heidelberg, Germany: Springer, 2015.
 
     """
+    warnings.warn((
+        "This function will be deprecated in pyfar 0.8.0 in favor "
+        "of spharpy.samplings.equiangular."),
+            PyfarDeprecationWarning)
+
     if (n_points is None) and (sh_order is None):
         raise ValueError(
             "Either the n_points or sh_order needs to be specified.")
@@ -223,8 +254,7 @@ def sph_equiangular(n_points=None, sh_order=None, radius=1.):
 
     # make Coordinates object
     sampling = pyfar.Coordinates(
-        phi.reshape(-1), theta.reshape(-1), rad,
-        domain='sph', convention='top_colat',
+        phi.reshape(-1), theta.reshape(-1), rad, 'sph', 'top_colat',
         comment='equiangular spherical sampling grid',
         weights=w, sh_order=n_max)
 
@@ -235,6 +265,9 @@ def sph_gaussian(n_points=None, sh_order=None, radius=1.):
     """
     Generate sampling of the sphere based on the Gaussian quadrature.
 
+    This function will be deprecated in pyfar 0.8.0 in favor
+    of :py:func:`spharpy.samplings.gaussian`.
+
     For detailed information, see [#]_ (Section 3.3).
     This sampling does not contain points at the North and South Pole and is
     typically used for spherical harmonics processing. See
@@ -264,6 +297,11 @@ def sph_gaussian(n_points=None, sh_order=None, radius=1.):
            Berlin, Heidelberg, Germany: Springer, 2015.
 
     """
+    warnings.warn((
+        "This function will be deprecated in pyfar 0.8.0 in favor "
+        "of spharpy.samplings.gaussian."),
+            PyfarDeprecationWarning)
+
     if (n_points is None) and (sh_order is None):
         raise ValueError(
             "Either the n_points or sh_order needs to be specified.")
@@ -303,8 +341,7 @@ def sph_gaussian(n_points=None, sh_order=None, radius=1.):
 
     # make Coordinates object
     sampling = pyfar.Coordinates(
-        phi.reshape(-1), theta.reshape(-1), rad,
-        domain='sph', convention='top_colat',
+        phi.reshape(-1), theta.reshape(-1), rad, 'sph', 'top_colat',
         comment='gaussian spherical sampling grid',
         weights=weights, sh_order=n_max)
 
@@ -315,6 +352,9 @@ def sph_extremal(n_points=None, sh_order=None, radius=1.):
     """
     Return a Hyperinterpolation sampling grid.
 
+    This function will be deprecated in pyfar 0.8.0 in favor
+    of :py:func:`spharpy.samplings.hyperinterpolation`.
+
     After Sloan and Womersley [#]_. The samplings are available for
     1 <= `sh_order` <= 200 (``n_points = (sh_order + 1)^2``).
 
@@ -350,6 +390,10 @@ def sph_extremal(n_points=None, sh_order=None, radius=1.):
     .. [#]  https://web.maths.unsw.edu.au/~rsw/Sphere/MaxDet/
 
     """
+    warnings.warn((
+        "This function will be deprecated in pyfar 0.8.0 in favor "
+        "of spharpy.samplings.hyperinterpolation."),
+            PyfarDeprecationWarning)
 
     if (n_points is None) and (sh_order is None):
         for o in range(1, 100):
@@ -409,6 +453,9 @@ def sph_t_design(degree=None, sh_order=None, criterion='const_energy',
     """
     Return spherical t-design sampling grid.
 
+    This function will be deprecated in pyfar 0.8.0 in favor
+    of :py:func:`spharpy.samplings.spherical_t_design`.
+
     For detailed information, see [#]_.
     For a spherical harmonic order :math:`n_{sh}`, a t-Design of degree
     :math:`t=2n_{sh}` for constant energy or :math:`t=2n_{sh}+1` additionally
@@ -466,6 +513,10 @@ def sph_t_design(degree=None, sh_order=None, criterion='const_energy',
     .. [#]  http://web.maths.unsw.edu.au/~rsw/Sphere/EffSphDes/sf.html
 
     """
+    warnings.warn((
+        "This function will be deprecated in pyfar 0.8.0 in favor "
+        "of spharpy.samplings.spherical_t_design."),
+            PyfarDeprecationWarning)
 
     # check input
     if (degree is None) and (sh_order is None):
@@ -539,6 +590,9 @@ def sph_equal_angle(delta_angles, radius=1.):
     """
     Generate sampling of the sphere with equally spaced angles.
 
+    This function will be deprecated in pyfar 0.8.0 in favor
+    of :py:func:`spharpy.samplings.equal_angle`.
+
     This sampling contain points at the North and South Pole. See
     :py:func:`sph_equiangular`, :py:func:`sph_gaussian`, and
     :py:func:`sph_great_circle` for samplings that do not contain points at the
@@ -561,6 +615,10 @@ def sph_equal_angle(delta_angles, radius=1.):
         :py:func:`calculate_sph_voronoi_weights`.
 
     """
+    warnings.warn((
+        "This function will be deprecated in pyfar 0.8.0 in favor "
+        "of spharpy.samplings.equal_angle."),
+            PyfarDeprecationWarning)
 
     # get the angles
     delta_angles = np.asarray(delta_angles)
@@ -591,9 +649,8 @@ def sph_equal_angle(delta_angles, radius=1.):
     theta = np.concatenate(([0], theta, [180]))
 
     # make Coordinates object
-    sampling = pyfar.Coordinates(
-        phi, theta, radius,
-        domain='sph', convention='top_colat', unit='deg',
+    sampling = pyfar.Coordinates.from_spherical_colatitude(
+        phi/180*np.pi, theta/180*np.pi, radius,
         comment='equal angle spherical sampling grid')
 
     return sampling
@@ -604,6 +661,9 @@ def sph_great_circle(elevation=np.linspace(-90, 90, 19), gcd=10, radius=1,
     """
     Spherical sampling grid according to the great circle distance criterion.
 
+    This function will be deprecated in pyfar 0.8.0 in favor
+    of :py:func:`spharpy.samplings.great_circle`.
+
     Sampling grid where neighboring points of the same elevation have approx.
     the same great circle distance across elevations [#]_.
 
@@ -640,8 +700,11 @@ def sph_great_circle(elevation=np.linspace(-90, 90, 19), gcd=10, radius=1,
             the head-related transfer functions of an artificial head with a
             high directional resolution,” 109th AES Convention, Los Angeles,
             USA, Sep. 2000.
-
     """
+    warnings.warn((
+        "This function will be deprecated in pyfar 0.8.0 in favor "
+        "of spharpy.samplings.great_circle."),
+            PyfarDeprecationWarning)
 
     # check input
     assert 1 / azimuth_res % 1 == 0, "1/azimuth_res must be an integer."
@@ -681,8 +744,8 @@ def sph_great_circle(elevation=np.linspace(-90, 90, 19), gcd=10, radius=1,
     azim = np.round(azim/azimuth_res) * azimuth_res
 
     # make Coordinates object
-    sampling = pyfar.Coordinates(
-        azim, elev, radius, 'sph', 'top_elev', 'deg',
+    sampling = pyfar.Coordinates.from_spherical_elevation(
+        azim/180*np.pi, elev/180*np.pi, radius,
         comment='spherical great circle sampling grid')
 
     return sampling
@@ -692,8 +755,11 @@ def sph_lebedev(n_points=None, sh_order=None, radius=1.):
     """
     Return Lebedev spherical sampling grid.
 
+    This function will be deprecated in pyfar 0.8.0 in favor
+    of :py:func:`spharpy.samplings.lebedev`.
+
     For detailed information, see [#]_. For a list of available values
-    for `n_points` and `sh_order` call :py:func:`sph_lebedev`.
+    for `n_points` and `sh_order` call :py:func:`lebedev`.
 
     Parameters
     ----------
@@ -727,6 +793,10 @@ def sph_lebedev(n_points=None, sh_order=None, radius=1.):
         getlebedevsphere
 
     """
+    warnings.warn((
+        "This function will be deprecated in pyfar 0.8.0 in favor "
+        "of spharpy.samplings.hyperinterpolation."),
+            PyfarDeprecationWarning)
 
     # possible degrees
     degrees = np.array([6, 14, 26, 38, 50, 74, 86, 110, 146, 170, 194, 230,
@@ -757,7 +827,7 @@ def sph_lebedev(n_points=None, sh_order=None, radius=1.):
                              Valid orders are: {}.".format(
                              ', '.join(str_orders)))
 
-        n_points = int(degrees[orders == sh_order])
+        n_points = int(np.squeeze(degrees[orders == sh_order]))
 
     # check if n_points is available
     if n_points not in degrees:
@@ -766,7 +836,7 @@ def sph_lebedev(n_points=None, sh_order=None, radius=1.):
                          are: {}.".format(', '.join(str_degrees)))
 
     # calculate sh_order
-    sh_order = int(orders[degrees == n_points])
+    sh_order = int(np.squeeze(orders[degrees == n_points]))
 
     # get the samlpling
     leb = external.lebedev_sphere(n_points)
@@ -789,6 +859,9 @@ def sph_fliege(n_points=None, sh_order=None, radius=1.):
     """
     Return Fliege-Maier spherical sampling grid.
 
+    This function will be deprecated in pyfar 0.8.0 in favor
+    of :py:func:`spharpy.samplings.fliege`.
+
     For detailed information, see [#]_. Call :py:func:`sph_fliege`
     for a list of possible values for `n_points` and `sh_order`.
 
@@ -883,8 +956,11 @@ def sph_fliege(n_points=None, sh_order=None, radius=1.):
            and corresponding cubature formulae,” IMA J. Numerical Analysis,
            Vol. 19, pp. 317–334, Apr. 1999, doi: 10.1093/imanum/19.2.317.
     .. [#] https://audiogroup.web.th-koeln.de/SOFiA_wiki/DOWNLOAD.html
-
     """
+    warnings.warn((
+        "This function will be deprecated in pyfar 0.8.0 in favor "
+        "of spharpy.samplings.fliege."),
+            PyfarDeprecationWarning)
 
     # possible values for n_points and sh_order
     points = np.array([4, 9, 16, 25, 36, 49, 64, 81, 100, 121, 144, 169, 196,
@@ -913,7 +989,7 @@ def sph_fliege(n_points=None, sh_order=None, radius=1.):
                               ', '.join(str_orders)))
 
         # assign n_points
-        n_points = int(points[orders == sh_order])
+        n_points = int(np.squeeze(points[orders == sh_order]))
     else:
         # check if n_points is available
         if n_points not in points:
@@ -922,7 +998,7 @@ def sph_fliege(n_points=None, sh_order=None, radius=1.):
                             are: {}.".format(', '.join(str_points)))
 
         # assign sh_order
-        sh_order = int(orders[points == n_points])
+        sh_order = int(np.squeeze(orders[points == n_points]))
 
     # get the sampling points
     fliege = sio.loadmat(os.path.join(
@@ -935,14 +1011,16 @@ def sph_fliege(n_points=None, sh_order=None, radius=1.):
         fliege[:, 0],
         fliege[:, 1],
         radius,
-        domain='sph', convention='top_colat', unit='rad',
+        'sph', 'top_colat',
         sh_order=sh_order, weights=fliege[:, 2],
         comment='spherical Fliege sampling grid')
 
-    # switch and invert coordinates in Cartesian representation to be
+    # switch and invert Coordinates in Cartesian representation to be
     # consistent with [1]
-    xyz = sampling.get_cart(convention='right')
-    sampling.set_cart(xyz[:, 1], xyz[:, 0], -xyz[:, 2])
+    xyz = sampling.cartesian
+    sampling.x = xyz[:, 1]
+    sampling.y = xyz[:, 0]
+    sampling.z = -xyz[:, 2]
 
     return sampling
 
@@ -951,6 +1029,9 @@ def sph_equal_area(n_points, radius=1.):
     """
     Sampling based on partitioning into faces with equal area.
 
+    This function will be deprecated in pyfar 0.8.0 in favor
+    of :py:func:`spharpy.samplings.equal_area`.
+
     For detailed information, see [#]_.
 
     Parameters
@@ -972,13 +1053,15 @@ def sph_equal_area(n_points, radius=1.):
     .. [#]  P. Leopardi, “A partition of the unit sphere into regions of equal
             area and small diameter,” Electronic Transactions on Numerical
             Analysis, vol. 25, no. 12, pp. 309–327, 2006.
-
     """
+    warnings.warn((
+        "This function will be deprecated in pyfar 0.8.0 in favor "
+        "of spharpy.samplings.equal_area."),
+            PyfarDeprecationWarning)
 
     point_set = external.eq_point_set(2, n_points)
     sampling = pyfar.Coordinates(
         point_set[0] * radius, point_set[1] * radius, point_set[2] * radius,
-        domain='cart', convention='right',
         comment='Equal area partitioning of the sphere.')
 
     return sampling
@@ -1015,7 +1098,10 @@ def _sph_extremal_load_data(orders='all'):
         url = "https://web.maths.unsw.edu.au/~rsw/Sphere/S2Pts/MD/"
         fileurl = url + filename
 
-        http_data = http.urlopen('GET', fileurl)
+        # Kontrolle ist gut, Vertrauen ist besser
+        with warnings.catch_warnings():
+            warnings.simplefilter("ignore", InsecureRequestWarning)
+            http_data = http.urlopen('GET', fileurl)
 
         # save the data
         if http_data.status == 200:
@@ -1045,7 +1131,7 @@ def _sph_t_design_load_data(degrees='all'):
         raise ValueError("degrees must an int, list, or string.")
 
     print("Loading t-design sampling points from \
-        https://web.maths.unsw.edu.au/~rsw/Sphere/EffSphDes/sf.html. \
+        http://web.maths.unsw.edu.au/~rsw/Sphere/EffSphDes/sf.html. \
         This might take a while but is only done once.")
 
     http = urllib3.PoolManager(cert_reqs=False)
@@ -1065,7 +1151,10 @@ def _sph_t_design_load_data(degrees='all'):
               "SF29-Nov-2012/"
         fileurl = url + filename
 
-        http_data = http.urlopen('GET', fileurl)
+        # Kontrolle ist gut, Vertrauen ist besser
+        with warnings.catch_warnings():
+            warnings.simplefilter("ignore", InsecureRequestWarning)
+            http_data = http.urlopen('GET', fileurl)
 
         # save the data
         if http_data.status == 200:
