@@ -327,6 +327,29 @@ def test_magic_getitem_allslice():
     npt.assert_allclose(signal[:]._data, time[:])
 
 
+def test_magic_getitem_ellipsis():
+    """Test slicing operations by the magic function __getitem__."""
+    signal = pf.Signal([[[1, 1, 1], [2, 2, 2]]], 44100)
+    npt.assert_allclose(signal[..., 0].time, np.atleast_2d([1, 1, 1]))
+    assert signal[..., 0].time.shape == (1, 3)
+
+
+@pytest.mark.parametrize('domain', ['time', 'freq'])
+def test_magic_getitem_error(domain):
+    """
+    Test if indexing that would return a subset of the samples or frequency
+    bins raises a key error.
+    """
+    signal = pf.Signal([[0, 0, 0, 0, 0], [1, 1, 1, 1, 1]], 1)
+    signal.domain = domain
+    # manually indexing too many dimensions
+    with pytest.raises(IndexError, match='Indexed dimensions must not exceed'):
+        signal[0, 1]
+    # indexing too many dimensions with ellipsis operator
+    with pytest.raises(IndexError, match='Indexed dimensions must not exceed'):
+        signal[0, 0, ..., 1]
+
+
 def test_magic_setitem():
     """Test the magic function __setitem__."""
     signal = Signal([1, 2, 3], 44100)
